@@ -6,8 +6,11 @@ def gegus():
     g = sys.version
     h = g.split(".")
     m = str(h[0])+str(h[1])
-    path_dir = "C:/Users/"+getpass.getuser()+"/AppData/Local/Programs/Python"
-    os.chdir("C:/Users/"+getpass.getuser()+"/AppData/Local/Programs/Python")
+    user_list = os.listdir("C:/Users/")
+    for q in user_list:
+        if os.path.isdir("C:/Users/"+q+"/AppData/Local/Programs/Python"):
+            path_dir = "C:/Users/"+q+"/AppData/Local/Programs/Python"
+            os.chdir("C:/Users/"+q+"/AppData/Local/Programs/Python")
     file_list = os.listdir(path_dir)
     for i in file_list:
         if os.path.isdir(i+"/Lib/site-packages/mminepy"):
